@@ -38,14 +38,17 @@ import (
 	"github.com/helmfile/vals/pkg/providers/httpjson"
 	"github.com/helmfile/vals/pkg/providers/k8s"
 	"github.com/helmfile/vals/pkg/providers/keychain"
+	"github.com/helmfile/vals/pkg/providers/oci"
 	"github.com/helmfile/vals/pkg/providers/onepassword"
 	"github.com/helmfile/vals/pkg/providers/onepasswordconnect"
 	"github.com/helmfile/vals/pkg/providers/pulumi"
 	"github.com/helmfile/vals/pkg/providers/s3"
+	"github.com/helmfile/vals/pkg/providers/scaleway"
 	"github.com/helmfile/vals/pkg/providers/sops"
 	"github.com/helmfile/vals/pkg/providers/ssm"
 	"github.com/helmfile/vals/pkg/providers/tfstate"
 	"github.com/helmfile/vals/pkg/providers/vault"
+	"github.com/helmfile/vals/pkg/providers/yclockbox"
 	"github.com/helmfile/vals/pkg/stringmapprovider"
 	"github.com/helmfile/vals/pkg/stringprovider"
 )
@@ -93,6 +96,7 @@ const (
 	ProviderAzureKeyVault      = "azurekeyvault"
 	ProviderEnvSubst           = "envsubst"
 	ProviderKeychain           = "keychain"
+	ProviderOCI                = "oci"
 	ProviderOnePassword        = "op"
 	ProviderOnePasswordConnect = "onepasswordconnect"
 	ProviderDoppler            = "doppler"
@@ -103,6 +107,8 @@ const (
 	ProviderHCPVaultSecrets    = "hcpvaultsecrets"
 	ProviderHttpJsonManager    = "httpjson"
 	ProviderBitwarden          = "bw"
+	ProviderLockbox            = "yclockbox"
+	ProviderScaleway           = "scw"
 )
 
 var (
@@ -209,6 +215,9 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 			// 2. Then extracts the value for key baz) from the result from step 1.
 			p := awssecrets.New(r.logger, conf)
 			return p, nil
+		case ProviderOCI:
+			p := oci.New(r.logger, conf)
+			return p, nil
 		case ProviderSOPS:
 			p := sops.New(r.logger, conf)
 			return p, nil
@@ -279,6 +288,12 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 		case ProviderBitwarden:
 			p := bitwarden.New(r.logger, conf)
 			return p, nil
+		case ProviderLockbox:
+			p := yclockbox.New(r.logger, conf)
+			return p, nil
+		case ProviderScaleway:
+			p := scaleway.New(r.logger, conf)
+			return p, nil
 		}
 		return nil, fmt.Errorf("no provider registered for scheme %q", scheme)
 	}
